@@ -18,6 +18,7 @@
  */
 
 #include "popupview.h"
+#include "dialogshadows_p.h"
 
 #include <QApplication>
 #include <QClipboard>
@@ -532,6 +533,11 @@ void PopupView::resizeEvent(QResizeEvent *event)
     }
 }
 
+void PopupView::showEvent(QShowEvent * event)
+{
+    DialogShadows::self()->addWindow(this);
+}
+
 void PopupView::paintEvent(QPaintEvent *event)
 {
     Q_UNUSED(event)
